MessageRenderError

Enum MessageRenderError 

#[non_exhaustive]
pub enum MessageRenderError {
Show 16 variants
#[non_exhaustive]
HeaderContainsRawNewline { name: String, },
#[non_exhaustive]
HeaderContainsControlCharacter { name: String, },
#[non_exhaustive]
HeaderContainsNonAscii { name: String, },
#[non_exhaustive]
InvalidHeaderName { name: String, },
#[non_exhaustive]
HeaderLineTooLong { name: String, }, DateFormat, EmptyMimeBoundary, InvalidMimeBoundary, MismatchedMimeBoundary, EmptyMultipartParts, MimeNestingTooDeep, InvalidMultipartContentType, UnsupportedAttachmentBody, InvalidContentId, UnsupportedBody, MessageValidation(MessageValidationError),
}
Errors returned while rendering an RFC 822/MIME message.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


#[non_exhaustive]
HeaderContainsRawNewline

A header value contains a raw carriage return or line feed.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
name: String

Invalid header name.



#[non_exhaustive]
HeaderContainsControlCharacter

A header value contains a forbidden control character.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
name: String

Invalid header name.



#[non_exhaustive]
HeaderContainsNonAscii

A header remains non-ASCII after applicable encoding.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
name: String

Invalid header name.



#[non_exhaustive]
InvalidHeaderName

A header name violates RFC 5322 field-name syntax.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
name: String

Invalid header name.



#[non_exhaustive]
HeaderLineTooLong

A header cannot be folded below the RFC 5322 hard line limit.

Fields

This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
name: String

Overlong header name.



DateFormat

The message date could not be formatted as RFC 2822.



EmptyMimeBoundary

A MIME boundary is empty.



InvalidMimeBoundary

A MIME boundary contains bytes forbidden by the supported grammar.



MismatchedMimeBoundary

The content-type boundary parameter differs from the part boundary.



EmptyMultipartParts

A multipart node contains no child parts.



MimeNestingTooDeep

A MIME tree exceeds MAX_MULTIPART_DEPTH.



InvalidMultipartContentType

A multipart node’s content type is not multipart/*.



UnsupportedAttachmentBody

An unresolved attachment reference cannot be rendered.



InvalidContentId

An attachment content id is not a valid message-id value.



UnsupportedBody

The message contains a body variant unsupported by this renderer.



MessageValidation(MessageValidationError)

The message failed baseline outbound validation.